rpc

package
v0.0.0-...-a160660 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 22, 2026 License: Apache-2.0 Imports: 21 Imported by: 10

Documentation

Overview

Package rpc contains RPC server implementations.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewConfigurationServer

func NewConfigurationServer() config.ConfigurationServer

NewConfigurationServer returns a new configuration server.

func NewInstancesServer

func NewInstancesServer() instances.InstancesServer

NewInstancesServer returns a new instances server.

func NewProjectsServer

func NewProjectsServer() projects.ProjectsServer

NewProjectsServer returns a new projects server.

Types

type Config

type Config struct {
}

Config implements config.ConfigurationServer.

func (*Config) Delete

Delete handles a request to delete a config. For app-internal use only.

func (*Config) Ensure

Ensure handles a request to create or update a config. For app-internal use only.

func (*Config) Get

Get handles a request to get a config.

func (*Config) List

List handles a request to list all configs.

func (*Config) Update

Update handles a request to update a config.

type Instances

type Instances struct {
}

Instances implements instances.InstancesServer.

func (*Instances) Delete

Delete handles a request to delete an instance asynchronously.

func (*Instances) Get

Get handles a request to get an existing instance.

func (*Instances) List

List handles a request to list instances.

type Projects

type Projects struct {
}

Projects implements projects.ProjectsServer.

func (*Projects) Delete

Delete handles a request to delete a project.

func (*Projects) Ensure

Ensure handles a request to create or update a project.

func (*Projects) Get

Get handles a request to get a project.

func (*Projects) List

List handles a request to list all projects.

Directories

Path Synopsis
internal
metrics
Package metrics is tsmon metrics for rpc API
Package metrics is tsmon metrics for rpc API
Package memory contains a RPC servers backed by in-memory storage.
Package memory contains a RPC servers backed by in-memory storage.

Jump to